| Filename 				                              | Description                           | Host Page                                                                                                 | Download Link                                                                                                                                             |
|--------------------------------------------|---------------------------------------|-----------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------|
| `2018_gem_cm_I9I10.txt.gz`                 | Mappings from ICD-9-CM to ICD-10-CM   | []()                                                                                                      | []()                                                                                                                                                      |
| `2018_gem_cm_I10I9.txt.gz`                 | Mappings from ICD-10-CM to ICD-9-CM   | []()                                                                                                      | []()                                                                                                                                                      |
| `2018_gem_pcs_I9I10.txt.gz`                | Mappings from ICD-9-PCS to ICD-10-PCS | []()                                                                                                      | []()                                                                                                                                                      |
| `2018_gem_pcs_I10I9.txt.gz`                | Mappings from ICD-10-PCS to ICD-9-PCS | []()                                                                                                      | []()                                                                                                                                                      |
| `HOM-ICD9.csv.gz`                          | ICD9 Hierarchical Description         | []()                                                                                                      | []()                                                                                                                                                      |
| `icd-10-cm-tabular-2025.xml.gz`            | ICD10-CM Hierarchical Description     | [ICD-10-CM Files - October 1, 2024, ICD-10-CM release](https://www.cdc.gov/nchs/icd/icd-10-cm/files.html) | [icd10cm-table-index-2025.zip](https://ftp.cdc.gov/pub/Health_Statistics/NCHS/Publications/ICD10CM/2025/icd10cm-table-index-2025.zip)                     |
| `icd10cm-codes-2025.txt.gz`                | Exaustive list of ICD10-CM            | [ICD-10-CM Files - October 1, 2024, ICD-10-CM release](https://www.cdc.gov/nchs/icd/icd-10-cm/files.html) | [ICD10-CM Code Descriptions 2025.zip](https://ftp.cdc.gov/pub/Health_Statistics/NCHS/Publications/ICD10CM/2025/ICD10-CM%20Code%20Descriptions%202025.zip) |
| `icd-10-cm-conversion-table-FY2025.csv.gz` | Legacy maps for ICD10-CM              | [ICD-10-CM Files - October 1, 2024, ICD-10-CM release](https://www.cdc.gov/nchs/icd/icd-10-cm/files.html) | [icd-10-cm-conversion-table-FY2025.xlsx](https://ftp.cdc.gov/pub/Health_Statistics/NCHS/Publications/ICD10CM/2025/icd-10-cm-conversion-table-FY2025.xlsx) |
| `icd10pcs_codes_2024.txt.gz`               | ICD10-PCS Flat Description            | [CMS ICD-10](https://www.cms.gov/medicare/coding-billing/icd-10-codes)                                    | [2024 ICD-10-PCS Codes File (ZIP)](https://www.cms.gov/files/zip/2024-icd-10-pcs-codes-file-updated-12/19/2023.zip)                                       |
| `icd10pcs_conversion_table.txt.gz`         | Legacy maps for ICD10-PCS             | [CMS ICD-10](https://www.cms.gov/medicare/coding-billing/icd-10-codes)                                    | [2024 ICD-10-PCS Conversion Table (ZIP)](https://www.cms.gov/files/zip/2024-icd-10-pcs-conversion-table-updated-12/19/2023.zip)                           |
